document.addEventListener('DOMContentLoaded', () => {
  const messages = document.getElementById('messages');
  const userInput = document.getElementById('userInput');
  const sendButton = document.getElementById('send-button');
  const themeToggle = document.querySelector('.theme-toggle');
  
  // Theme handling
  const toggleTheme = () => {
    const isDark = document.body.getAttribute('data-theme') === 'dark';
    document.body.setAttribute('data-theme', isDark ? 'light' : 'dark');
    themeToggle.textContent = isDark ? '🌙' : '☀️';
    localStorage.setItem('theme', isDark ? 'light' : 'dark');
  };

  // Load saved theme
  const savedTheme = localStorage.getItem('theme');
  if (savedTheme) {
    document.body.setAttribute('data-theme', savedTheme);
    themeToggle.textContent = savedTheme === 'dark' ? '☀️' : '🌙';
  }

  themeToggle.addEventListener('click', toggleTheme);

  // Auto-resize textarea
  const textarea = document.getElementById('user-input');
  textarea.addEventListener('input', () => {
    textarea.style.height = 'auto';
    textarea.style.height = textarea.scrollHeight + 'px';
  });

  // Send message handling
  const addMessage = (content, isUser = false) => {
    const messageDiv = document.createElement('div');
    messageDiv.className = `message ${isUser ? 'user' : 'assistant'}`;
    
    const avatar = document.createElement('div');
    avatar.className = 'avatar';
    avatar.textContent = isUser ? 'U' : 'C';
    
    const contentDiv = document.createElement('div');
    contentDiv.className = 'content';
    contentDiv.innerHTML = `<p>${content}</p>`;
    
    messageDiv.appendChild(avatar);
    messageDiv.appendChild(contentDiv);
    messages.appendChild(messageDiv);
    messages.scrollTop = messages.scrollHeight;
  };

  const handleSend = () => {
    const content = textarea.value.trim();
    if (!content) return;
    
    addMessage(content, true);
    textarea.value = '';
    textarea.style.height = 'auto';
    
    // Simulate response
    setTimeout(() => {
      addMessage("I'm a simulated response in this interface demo.");
    }, 1000);
  };

  sendButton.addEventListener('click', handleSend);
  textarea.addEventListener('keydown', (e) => {
    if (e.key === 'Enter' && !e.shiftKey) {
      e.preventDefault();
      handleSend();
    }
  });
});